##  Introduction
Before setting up microservice discovery, provision the self-built software discovery feature in your SAP LeanIX workspace. Provisioning extends the meta model by adding the microservice fact sheet subtype, along with essential fields and relations. This enables discovered microservices to be added as fact sheets and linked to relevant business applications, and responsible teams. For more details on what fields and relations are added, [Meta Model Extension](https://help.sap.com/docs/leanix/ea/workspace-setup-for-self-built-software-discovery?locale=en-US&state=PRODUCTION&version=CLOUD#loio275e3cdd7a44101488219c38543d47a2__meta_model_extension).
